@@ -1,7 +1,6 @@
 #
-# Copyright (c) 1995-2015 Jarkko Hietaniemi. All rights reserved.
-# This program is free software; you can redistribute it and/or
-# modify it under the same terms as Perl itself.
+# Copyright (c) 1995-2016 Jarkko Hietaniemi. All rights reserved.
+# For license see COPYRIGHT and LICENSE later in this file.
 #
 # Resource.pm
 #
@@ -13,7 +12,7 @@ package BSD::Resource;
 use strict;
 use vars qw(@ISA @EXPORT @EXPORT_OK $AUTOLOAD $VERSION);
 
-$VERSION = '1.2909';
+$VERSION = '1.2910';
 
 use Carp;
 use AutoLoader;
@@ -24,11 +23,17 @@ require DynaLoader;
 @ISA = qw(Exporter DynaLoader);
 
 @EXPORT = qw(
+	     PRIO_CONTRACT
+	     PRIO_LWP
 	     PRIO_MAX
 	     PRIO_MIN
 	     PRIO_PGRP
 	     PRIO_PROCESS
+	     PRIO_PROJECT
+	     PRIO_SESSION
+	     PRIO_TASK
 	     PRIO_USER
+	     PRIO_ZONE
 	     RLIMIT_AIO_MEM
 	     RLIMIT_AIO_OPS
 	     RLIMIT_AS
@@ -36,6 +41,7 @@ require DynaLoader;
 	     RLIMIT_CPU
 	     RLIMIT_DATA
 	     RLIMIT_FSIZE
+	     RLIMIT_FREEMEM
 	     RLIMIT_LOCKS
 	     RLIMIT_MEMLOCK
 	     RLIMIT_MSGQUEUE
@@ -43,9 +49,11 @@ require DynaLoader;
 	     RLIMIT_NOFILE
 	     RLIMIT_NPROC
 	     RLIMIT_NPTS
+	     RLIMIT_NTHR
 	     RLIMIT_OFILE
 	     RLIMIT_OPEN_MAX
 	     RLIMIT_PTHREAD
+	     RLIMIT_RSESTACK
 	     RLIMIT_RSS
 	     RLIMIT_RTPRIO
 	     RLIMIT_RTTIME
@@ -66,7 +74,7 @@ require DynaLoader;
 	     get_rlimits
 	     getpriority
 	     getrlimit
-	     getrusage	
+	     getrusage
 	     setpriority
 	     setrlimit
 );
@@ -271,9 +279,16 @@ The $resource argument can be one of
         RLIMIT_AIO_OPS          maximum number          1
                                 for POSIX AIO ops
 
+        RLIMIT_FREEMEM          portion of the total memory
+
+        RLIMIT_NTHR             maximum number of       1
+                                threads
+
         RLIMIT_NPTS             maximum number of       1
                                 pseudo-terminals
 
+        RLIMIT_RSESTACK         RSE stack size          bytes
+
         RLIMIT_SBSIZE           socket buffer size      bytes
 
         RLIMIT_SWAP             maximum swap size       bytes
@@ -520,7 +535,7 @@ at all so it stays zero.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 1995-2015 Jarkko Hietaniemi All Rights Reserved
+Copyright 1995-2016 Jarkko Hietaniemi All Rights Reserved
 
 This module free software; you can redistribute it and/or modify it
 under the terms of the Artistic License 2.0 or GNU Lesser General
